# Event Terms List for Use with the Common Alerting Protocol Version 1.2
# Adapted from the OASIS Event Terms List Version 1.2 (OETv1.2)
# https://docs.oasis-open.org/emergency/cap-etl/v1.2/cn01/cap-etl-v1.2-cn01.html

OASIS_EVENT_TERMS = [
    {"code": "OET-000", "term": "other event", "categories": ["Other"]},
    {"code": "OET-001", "term": "active shooter situation", "categories": ["Safety", "Security"]},
    {"code": "OET-002", "term": "administrative activity", "categories": ["Other"]},
    {"code": "OET-003", "term": "air hazard", "categories": ["Met", "Transport"]},
    {"code": "OET-004", "term": "air quality", "categories": ["Env", "Health"]},
    {"code": "OET-005", "term": "air search", "categories": ["Met"]},
    {"code": "OET-006", "term": "air stagnation", "categories": ["Met"]},
    {"code": "OET-007", "term": "aircraft crash", "categories": ["Transport"]},
    {"code": "OET-008", "term": "aircraft incident", "categories": ["Transport"]},
    {"code": "OET-009", "term": "airport closure", "categories": ["Transport"]},
    {"code": "OET-010", "term": "airspace closure", "categories": ["Transport"]},
    {"code": "OET-011", "term": "airspace restriction", "categories": ["Transport"]},
    {"code": "OET-012", "term": "ambulance", "categories": ["Health"]},
    {"code": "OET-013", "term": "animal disease", "categories": ["Health"]},
    {"code": "OET-014", "term": "animal feed", "categories": ["Health"]},
    {"code": "OET-015", "term": "animal health", "categories": ["Health"]},
    {"code": "OET-016", "term": "arctic outflow", "categories": ["Met"]},
    {"code": "OET-017", "term": "ashfall",
     "categories": ["Geo", "Health", "Met", "Safety", "Transport"]},
    {"code": "OET-018", "term": "avalanche", "categories": ["Geo"]},
    {"code": "OET-019", "term": "aviation hazard", "categories": ["Transport"]},
    {"code": "OET-020", "term": "aviation security", "categories": ["Transport", "Security"]},
    {"code": "OET-021", "term": "beach hazard", "categories": ["Safety"]},
    {"code": "OET-022", "term": "biological", "categories": ["CBRNE"]},
    {"code": "OET-023", "term": "blizzard", "categories": ["Met"]},
    {"code": "OET-024", "term": "blood supply", "categories": ["Health"]},
    {"code": "OET-025", "term": "blowing dust", "categories": ["Met"]},
    {"code": "OET-026", "term": "blowing snow", "categories": ["Met"]},
    {"code": "OET-027", "term": "blue-green algae", "categories": ["Env"]},
    {"code": "OET-028", "term": "bomb threat", "categories": ["CBRNE"]},
    {"code": "OET-029", "term": "bridge closure", "categories": ["Transport"]},
    {"code": "OET-030", "term": "bridge collapse", "categories": ["Transport"]},
    {"code": "OET-031", "term": "building collapse", "categories": ["Infra"]},
    {"code": "OET-032", "term": "building structure hazard", "categories": ["Geo"]},
    {"code": "OET-033", "term": "bush fire", "categories": ["Fire"]},
    {"code": "OET-034", "term": "cable service issue", "categories": ["Infra"]},
    {"code": "OET-035", "term": "canal", "categories": ["Infra"]},
    {"code": "OET-036", "term": "chemical fire", "categories": ["CBRNE", "Fire"]},
    {"code": "OET-037", "term": "chemical hazard", "categories": ["CBRNE"]},
    {"code": "OET-038", "term": "child abduction", "categories": ["Safety", "Security"]},
    {"code": "OET-039", "term": "civil", "categories": ["Security"]},
    {"code": "OET-040", "term": "civil protest", "categories": ["Safety"]},
    {"code": "OET-041", "term": "coal gas", "categories": ["Infra"]},
    {"code": "OET-042", "term": "coastal flood", "categories": ["Met"]},
    {"code": "OET-043", "term": "cold", "categories": ["Met"]},
    {"code": "OET-044", "term": "cold weather", "categories": ["Met"]},
    {"code": "OET-045", "term": "communications service disruption", "categories": ["Infra"]},
    {"code": "OET-046", "term": "contagious disease", "categories": ["Health"]},
    {"code": "OET-047", "term": "contaminated water", "categories": ["Health"]},
    {"code": "OET-048", "term": "contamination", "categories": ["CBRNE", "Health"]},
    {"code": "OET-049", "term": "criminal activity", "categories": ["Safety"]},
    {"code": "OET-050", "term": "cybercrime threat", "categories": ["Safety", "Security"]},
    {"code": "OET-051", "term": "cyclone", "categories": ["Met"]},
    {"code": "OET-052", "term": "dam break", "categories": ["Geo", "Met"]},
    {"code": "OET-053", "term": "dam issue", "categories": ["Infra"]},
    {"code": "OET-054", "term": "dangerous animal", "categories": ["Safety"]},
    {"code": "OET-055", "term": "dangerous person threat", "categories": ["Safety"]},
    {"code": "OET-056", "term": "debris flow", "categories": ["Geo"]},
    {"code": "OET-057", "term": "demonstration", "categories": ["Other"]},
    {"code": "OET-058", "term": "dense fog", "categories": ["Met"]},
    {"code": "OET-059", "term": "dense smoke", "categories": ["Met"]},
    {"code": "OET-060", "term": "diesel fuel issue", "categories": ["Infra"]},
    {"code": "OET-061", "term": "disease", "categories": ["Health"]},
    {"code": "OET-062", "term": "disease outbreak", "categories": ["Health"]},
    {"code": "OET-063", "term": "drought", "categories": ["Met"]},
    {"code": "OET-064", "term": "drug safety", "categories": ["Health"]},
    {"code": "OET-065", "term": "drug supply", "categories": ["Health"]},
    {"code": "OET-066", "term": "dust storm", "categories": ["Met"]},
    {"code": "OET-067", "term": "dyke break", "categories": ["Met"]},
    {"code": "OET-068", "term": "earthquake", "categories": ["Geo"]},
    {"code": "OET-069", "term": "electronic infrastructure", "categories": ["Infra"]},
    {"code": "OET-070", "term": "emergency responder incident", "categories": ["Safety"]},
    {"code": "OET-071", "term": "emergency responder threat", "categories": ["Safety"]},
    {"code": "OET-072", "term": "emergency support facilities incident", "categories": ["Infra"]},
    {"code": "OET-073", "term": "emergency support services incident", "categories": ["Infra"]},
    {"code": "OET-074", "term": "emergency telephone outage", "categories": ["Infra"]},
    {"code": "OET-075", "term": "environmental issue", "categories": ["Env"]},
    {"code": "OET-076", "term": "explosion threat", "categories": ["CBRNE"]},
    {"code": "OET-077", "term": "falling object", "categories": ["Safety"]},
    {"code": "OET-078", "term": "fire", "categories": ["Fire"]},
    {"code": "OET-079", "term": "flash flood", "categories": ["Met"]},
    {"code": "OET-080", "term": "flash freeze", "categories": ["Met"]},
    {"code": "OET-081", "term": "flood", "categories": ["Met"]},
    {"code": "OET-082", "term": "fog", "categories": ["Met"]},
    {"code": "OET-083", "term": "food contamination", "categories": ["Health"]},
    {"code": "OET-084", "term": "food safety", "categories": ["Health"]},
    {"code": "OET-085", "term": "food supply", "categories": ["Health"]},
    {"code": "OET-086", "term": "forest fire", "categories": ["Fire"]},
    {"code": "OET-087", "term": "freeze", "categories": ["Met"]},
    {"code": "OET-088", "term": "freezing drizzle", "categories": ["Met"]},
    {"code": "OET-089", "term": "freezing rain", "categories": ["Met"]},
    {"code": "OET-090", "term": "freezing spray", "categories": ["Met"]},
    {"code": "OET-091", "term": "frost", "categories": ["Met"]},
    {"code": "OET-092", "term": "fuel issue", "categories": ["Infra"]},
    {"code": "OET-093", "term": "geophysical issue", "categories": ["Geo"]},
    {"code": "OET-094", "term": "grass fire", "categories": ["Fire"]},
    {"code": "OET-095", "term": "hail", "categories": ["Met"]},
    {"code": "OET-096", "term": "hazardous seas", "categories": ["Transport"]},
    {"code": "OET-097", "term": "health issue", "categories": ["Health"]},
    {"code": "OET-098", "term": "heat", "categories": ["Met"]},
    {"code": "OET-099", "term": "heating oil issue", "categories": ["Infra"]},
    {"code": "OET-100", "term": "high seas", "categories": ["Met"]},
    {"code": "OET-101", "term": "high surf", "categories": ["Met"]},
    {"code": "OET-102", "term": "high tide", "categories": ["Transport"]},
    {"code": "OET-103", "term": "high water", "categories": ["Infra", "Transport"]},
    {"code": "OET-104", "term": "home crime", "categories": ["Safety"]},
    {"code": "OET-105", "term": "humidity issue", "categories": ["Met"]},
    {"code": "OET-106", "term": "hurricane", "categories": ["Met"]},
    {"code": "OET-107", "term": "ice", "categories": ["Met"]},
    {"code": "OET-108", "term": "ice pressure issue", "categories": ["Met"]},
    {"code": "OET-109", "term": "ice storm", "categories": ["Met"]},
    {"code": "OET-110", "term": "iceberg", "categories": ["Met"]},
    {"code": "OET-111", "term": "industrial crime", "categories": ["Safety"]},
    {"code": "OET-112", "term": "industrial facility", "categories": ["Safety"]},
    {"code": "OET-113", "term": "industrial fire", "categories": ["Fire"]},
    {"code": "OET-114", "term": "infrastructure", "categories": ["Infra"]},
    {"code": "OET-115", "term": "internet service", "categories": ["Infra"]},
    {"code": "OET-116", "term": "lake effect snow", "categories": ["Met"]},
    {"code": "OET-117", "term": "lake wind", "categories": ["Met"]},
    {"code": "OET-118", "term": "landline service", "categories": ["Infra"]},
    {"code": "OET-119", "term": "landslide", "categories": ["Geo"]},
    {"code": "OET-120", "term": "law enforcement", "categories": ["Security"]},
    {"code": "OET-121", "term": "levee break", "categories": ["Met"]},
    {"code": "OET-122", "term": "lightning", "categories": ["Met"]},
    {"code": "OET-123", "term": "limited visibility", "categories": ["Transport"]},
    {"code": "OET-124", "term": "low tide", "categories": ["Transport"]},
    {"code": "OET-125", "term": "low water", "categories": ["Infra", "Transport"]},
    {"code": "OET-126", "term": "low water pressure", "categories": ["Infra"]},
    {"code": "OET-127", "term": "meteoroid", "categories": ["Transport"]},
    {"code": "OET-128", "term": "meteorological issue", "categories": ["Met"]},
    {"code": "OET-129", "term": "missile threat", "categories": ["CBRNE"]},
    {"code": "OET-130", "term": "missing person(s)", "categories": ["Safety"]},
    {"code": "OET-131", "term": "mobile communication", "categories": ["Infra"]},
    {"code": "OET-132", "term": "monsoon", "categories": ["Met"]},
    {"code": "OET-133", "term": "mudslide", "categories": ["Geo"]},
    {"code": "OET-134", "term": "natural gas", "categories": ["Infra"]},
    {"code": "OET-135", "term": "network message notification", "categories": ["Other"]},
    {"code": "OET-136", "term": "nuclear power plant", "categories": ["Infra", "CBRNE"]},
    {"code": "OET-137", "term": "oil leak", "categories": ["Env"]},
    {"code": "OET-138", "term": "oil spill", "categories": ["Env"]},
    {"code": "OET-139", "term": "over water search", "categories": ["Rescue"]},
    {"code": "OET-140", "term": "overland flood", "categories": ["Met"]},
    {"code": "OET-141", "term": "overland search", "categories": ["Rescue"]},
    {"code": "OET-142", "term": "pipeline rupture", "categories": ["Infra"]},
    {"code": "OET-143", "term": "plant health issue", "categories": ["Health"]},
    {"code": "OET-144", "term": "potable water", "categories": ["Infra"]},
    {"code": "OET-145", "term": "power outage", "categories": ["Infra"]},
    {"code": "OET-146", "term": "power utility", "categories": ["Infra"]},
    {"code": "OET-147", "term": "practice", "categories": ["Other"]},
    {"code": "OET-148", "term": "product safety", "categories": ["Safety"]},
    {"code": "OET-149", "term": "public facility", "categories": ["Infra"]},
    {"code": "OET-150", "term": "public health", "categories": ["Health"]},
    {"code": "OET-151", "term": "public service issue", "categories": ["Infra"]},
    {"code": "OET-152", "term": "public transit issue", "categories": ["Transport"]},
    {"code": "OET-153", "term": "pyroclastic flow", "categories": ["Geo"]},
    {"code": "OET-154", "term": "radiation", "categories": ["CBRNE"]},
    {"code": "OET-155", "term": "radio transmitter", "categories": ["Infra"]},
    {"code": "OET-156", "term": "radioactive material release", "categories": ["CBRNE"]},
    {"code": "OET-157", "term": "radiological fire", "categories": ["CBRNE", "Fire"]},
    {"code": "OET-158", "term": "railway issue", "categories": ["Transport"]},
    {"code": "OET-159", "term": "rain", "categories": ["Met"]},
    {"code": "OET-160", "term": "rapid ice closing of water passage", "categories": ["Transport"]},
    {"code": "OET-161", "term": "red tide", "categories": ["Health"]},
    {"code": "OET-162", "term": "rescue", "categories": ["Rescue"]},
    {"code": "OET-163", "term": "retail crime issue", "categories": ["Safety"]},
    {"code": "OET-164", "term": "rip current issue", "categories": ["Safety"]},
    {"code": "OET-165", "term": "road closure", "categories": ["Transport"]},
    {"code": "OET-166", "term": "road issue", "categories": ["Transport"]},
    {"code": "OET-167", "term": "road vehicle accident", "categories": ["Transport"]},
    {"code": "OET-168", "term": "rogue waves", "categories": ["Geo"]},
    {"code": "OET-169", "term": "safety", "categories": ["Safety"]},
    {"code": "OET-170", "term": "sandstorm", "categories": ["Met"]},
    {"code": "OET-171", "term": "satellite debris", "categories": ["Other"]},
    {"code": "OET-172", "term": "satellite service", "categories": ["Infra"]},
    {"code": "OET-173", "term": "school bus issue", "categories": ["Transport"]},
    {"code": "OET-174", "term": "school closing", "categories": ["Infra"]},
    {"code": "OET-175", "term": "school lockdown", "categories": ["Infra"]},
    {"code": "OET-176", "term": "search event", "categories": ["Rescue"]},
    {"code": "OET-177", "term": "security", "categories": ["Security"]},
    {"code": "OET-178", "term": "sewer", "categories": ["Infra"]},
    {"code": "OET-179", "term": "shoreline threat", "categories": ["Safety"]},
    {"code": "OET-180", "term": "sinkhole", "categories": ["Safety"]},
    {"code": "OET-181", "term": "sleet", "categories": ["Met"]},
    {"code": "OET-182", "term": "snow", "categories": ["Met"]},
    {"code": "OET-183", "term": "snowstorm", "categories": ["Met"]},
    {"code": "OET-184", "term": "space debris", "categories": ["Other"]},
    {"code": "OET-185", "term": "space weather", "categories": ["Other"]},
    {"code": "OET-186", "term": "squall", "categories": ["Met"]},
    {"code": "OET-187", "term": "storm", "categories": ["Met"]},
    {"code": "OET-188", "term": "storm drain", "categories": ["Infra"]},
    {"code": "OET-189", "term": "storm surge", "categories": ["Met"]},
    {"code": "OET-190", "term": "structure fire", "categories": ["Fire"]},
    {"code": "OET-191", "term": "swells", "categories": ["Safety", "Transport"]},
    {"code": "OET-192", "term": "telephone", "categories": ["Infra"]},
    {"code": "OET-193", "term": "terrorist incident", "categories": ["Safety"]},
    {"code": "OET-194", "term": "thunderstorm", "categories": ["Met"]},
    {"code": "OET-195", "term": "tornadic waterspout", "categories": ["Met"]},
    {"code": "OET-196", "term": "tornado", "categories": ["Met"]},
    {"code": "OET-197", "term": "toxic plume", "categories": ["CBRNE"]},
    {"code": "OET-198", "term": "toxic spill", "categories": ["CBRNE"]},
    {"code": "OET-199", "term": "traffic", "categories": ["Transport"]},
    {"code": "OET-200", "term": "transportation", "categories": ["Transport"]},
    {"code": "OET-201", "term": "tropical depression", "categories": ["Met"]},
    {"code": "OET-202", "term": "tropical storm", "categories": ["Mer"]},
    {"code": "OET-203", "term": "tsunami", "categories": ["Geo"]},
    {"code": "OET-204", "term": "typhoon", "categories": ["Met"]},
    {"code": "OET-205", "term": "ultraviolet", "categories": ["Safety"]},
    {"code": "OET-206", "term": "utility", "categories": ["Infra"]},
    {"code": "OET-207", "term": "vehicle crime", "categories": ["Safety"]},
    {"code": "OET-208", "term": "volcanic activity", "categories": ["Geo"]},
    {"code": "OET-209", "term": "volcanic eruption", "categories": ["Geo"]},
    {"code": "OET-210", "term": "volcanic lahar", "categories": ["Geo"]},
    {"code": "OET-211", "term": "volcanic lava", "categories": ["Geo"]},
    {"code": "OET-212", "term": "waste management", "categories": ["Infra"]},
    {"code": "OET-213", "term": "water", "categories": ["Geo", "Transport"]},
    {"code": "OET-214", "term": "water main break", "categories": ["Infra"]},
    {"code": "OET-215", "term": "waterspout", "categories": ["Met"]},
    {"code": "OET-216", "term": "weather", "categories": ["Met"]},
    {"code": "OET-217", "term": "wildfire", "categories": ["Fire"]},
    {"code": "OET-218", "term": "wind", "categories": ["Met"]},
    {"code": "OET-219", "term": "wind change", "categories": ["Met"]},
    {"code": "OET-220", "term": "wind chill", "categories": ["Met"]},
    {"code": "OET-221", "term": "wind shear", "categories": ["Met"]},
    {"code": "OET-222", "term": "winter storm", "categories": ["Met"]},
    {"code": "OET-223", "term": "winter weather", "categories": ["Met"]},
]

OASIS_EVENT_TERMS_BY_CODE = {x['code']: x for x in OASIS_EVENT_TERMS}

OASIS_EVENT_TERMS_AS_CHOICES = [(x['code'], x['term'], x['categories']) for x in OASIS_EVENT_TERMS]
